@@ -7,12 +7,14 @@ from sqlalchemy.types import DateTime
 
 
 class utc_now(FunctionElement):
+    """Current timestamp in UTC timezone"""
+
     type = DateTime()
 
 
 @compiles(utc_now, "postgresql")
 def pg(element: utc_now, compiler: SQLCompiler, **kw: Dict[str, Any]) -> SQLCompiler:
-    return "TIMEZONE('utc', CURRENT_TIMESTAMP)"
+    return "timezone('utc', current_timestamp)"
 
 
 @compiles(utc_now, "sqlite")
